@@ -18,7 +18,7 @@ import os
 import glob
 import re
 from . import read_meter
-from matplotlib import pyplot as plt
+
 
 
 # detect if the calibrator is present
@@ -103,6 +103,11 @@ def run(cur_phase,meter, replay=False,debug=False):
     norm_coeffs = np.array(sensor_coeffs)
     #----DEBUG vector visualization----
     if(debug):
+        try:
+            from matplotlib import pyplot as plt
+        except:
+            print("Error setting up visualization, do you have an X11 server?")
+            exit(1)
         #--plot raw P,Q outputs for each sensor--
         raw_figs = []
         for i in range(len(sensor_coeffs)):
