@@ -1,7 +1,7 @@
 import sys
 import numpy as np
 import scipy
-from joule.utils.time import (timestamp_to_human,
+from joule.utilities import (timestamp_to_human,
                               seconds_to_timestamp)
 
 
